@@ -58,6 +58,18 @@ def test_root_parameter_pass_by(monkeypatch, tmpdir):
     setuptools_scm.get_version(root=tmpdir.strpath)
 
 
+def test_parentdir_prefix(tmpdir, monkeypatch):
+    monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
+    p = tmpdir.ensure("projectname-v12.34", dir=True)
+    p.join("setup.py").write(
+        """from setuptools import setup
+setup(use_scm_version={"parentdir_prefix_version": "projectname-"})
+"""
+    )
+    res = do((sys.executable, "setup.py", "--version"), p)
+    assert res == "12.34"
+
+
 def test_fallback(tmpdir, monkeypatch):
     monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
     p = tmpdir.ensure("sub/package", dir=1)
@@ -78,10 +90,14 @@ def test_pretended(version, monkeypatch):
     assert setuptools_scm.get_version() == version
 
 
-def test_root_relative_to(monkeypatch, tmpdir):
-    assert_root(monkeypatch, tmpdir.join("alt").strpath)
-    __file__ = tmpdir.join("module/file.py").strpath
-    setuptools_scm.get_version(root="../alt", relative_to=__file__)
+def test_root_relative_to(monkeypatch, tmp_path):
+    assert_root(monkeypatch, str(tmp_path / "alt"))
+    module = tmp_path / "module/file.py"
+    module.parent.mkdir()
+    module.touch()
+    setuptools_scm.get_version(root="../alt", relative_to=str(module))
+    with pytest.warns(UserWarning, match="relative_to is expected to be a file.*"):
+        setuptools_scm.get_version(root="../alt", relative_to=str(module.parent))
 
 
 def test_dump_version(tmpdir):
@@ -89,9 +105,13 @@ def test_dump_version(tmpdir):
 
     dump_version(sp, "1.0", "first.txt")
     assert tmpdir.join("first.txt").read() == "1.0"
-    dump_version(sp, "1.0", "first.py")
+
+    dump_version(sp, "1.0.dev42", "first.py")
     content = tmpdir.join("first.py").read()
-    assert repr("1.0") in content
+    lines = content.splitlines()
+    assert "version = '1.0.dev42'" in lines
+    assert "version_tuple = (1, 0, 'dev42')" in lines
+
     import ast
 
     ast.parse(content)
